import "@jupyterlab/codemirror"
import "@jupyterlab/docregistry"
import "@jupyterlab/outputarea"
import "@jupyterlab/rendermime"
import "@jupyterlab/services"
import "@jupyterlab/theme-light-extension"
import "@phosphor/signaling"
import "@phosphor/widgets"

import './jupyterlab-styles'